mangadap.contrib package
========================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.contrib.LambdaR_2D_forMaNGA
   mangadap.contrib.xjmc

Module contents
---------------

.. automodule:: mangadap.contrib
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
